@@ -51,7 +51,7 @@ meanf <- function(x,h=10,level=c(80,95),fan=FALSE, lambda=NULL)
 
   junk <- list(method="Mean",level=level,x=x,xname=xname,mean=ts(f,start=tsp(x)[2]+1/freq,f=freq),lower=lower,upper=upper,
         model=list(mu=f[1],mu.se=s/sqrt(length(x)),sd=s), lambda=lambda,
-        fitted =ts(fits,start=start.x+1/freq,f=freq), residuals=ts(res,start=start.x+1/freq,f=freq))
+        fitted =ts(c(NA,fits),start=start.x,f=freq), residuals=ts(c(NA,res),start=start.x,f=freq))
   junk$model$call <- match.call()
 
   return(structure(junk,class="forecast"))
@@ -92,73 +92,74 @@ thetaf <- function(x,h=10,level=c(80,95),fan=FALSE)
 # Random walk
 rwf <- function(x,h=10,drift=FALSE,level=c(80,95),fan=FALSE,lambda=NULL)
 {
-    xname <- deparse(substitute(x))
-    n <- length(x)
-    nn <- 1:h
-    if(!is.ts(x))
-        x <- ts(x)
-		if(!is.null(lambda))
-		{
-			origx <- x
-			x <- BoxCox(x,lambda)
-		}
-    if(drift)
-    {
-        fit <- summary(lm(diff(x) ~ 1))
-        b <- fit$coefficients[1,1]
-        b.se <- fit$coefficients[1,2]
-        s <- fit$sigma
-        res <- residuals(fit)
-        method <- "Random walk with drift"
-    }
-    else
-    {
-        b <- b.se <- 0
-        s <- sd(diff(x),na.rm=TRUE)
-        res <- diff(x)
-        method <- "Random walk"
-    }
-    f <- x[n] + nn*b
-    se <- sqrt((nn*s^2) + (nn*b.se)^2)
+  xname <- deparse(substitute(x))
+  n <- length(x)
+  freq=frequency(x)
+  nn <- 1:h
+  if(!is.ts(x))
+    x <- ts(x)
+  if(!is.null(lambda))
+  {
+    origx <- x
+    x <- BoxCox(x,lambda)
+  }
+  if(drift)
+  {
+    fit <- summary(lm(diff(x) ~ 1))
+    b <- fit$coefficients[1,1]
+    b.se <- fit$coefficients[1,2]
+    s <- fit$sigma
+    res <- ts(c(NA,residuals(fit)))
+    method <- "Random walk with drift"
+  }
+  else
+  {
+    b <- b.se <- 0
+    s <- sd(diff(x),na.rm=TRUE)
+#    fits <- ts(x[-n],start=tsp(x)[1]+1/freq,f=freq)
+    res <- ts(c(NA,diff(x)))
+    method <- "Random walk"
+  }
+  tsp(res) <- tsp(x)
+  f <- x[n] + nn*b
+  se <- sqrt((nn*s^2) + (nn*b.se)^2)
 
-    if(fan)
-        level <- seq(51,99,by=3)
-    else
-    {
-        if(min(level) > 0 & max(level) < 1)
-            level <- 100*level
-        else if(min(level) < 0 | max(level) > 99.99)
-            stop("Confidence limit out of range")
-    }
-    nconf <- length(level)
-    z <- qnorm(.5 + level/200)
-    lower <- upper <- matrix(NA,nrow=h,ncol=nconf)
-    for(i in 1:nconf)
-    {
-        lower[,i] <- f - z[i]*se
-        upper[,i] <- f + z[i]*se
-    }
-    freq=frequency(x)
-    lower <- ts(lower,start=tsp(x)[2]+1/freq,f=freq)
-    upper <- ts(upper,start=tsp(x)[2]+1/freq,f=freq)
-    colnames(lower) <- colnames(upper) <- paste(level,"%",sep="")
-		fits <- ts(x[-n],start=tsp(x)[1]+1/freq,f=freq)
-		fcast <- ts(f,start=tsp(x)[2]+1/freq,f=freq)
-	res <- diff(x)
-		if(!is.null(lambda))
-		{
-			x <- origx
-			fcast <- InvBoxCox(fcast,lambda)
-			fits <- InvBoxCox(fits,lambda)
-			upper <- InvBoxCox(upper,lambda)
-			lower <- InvBoxCox(lower,lambda)
-		}
+  if(fan)
+    level <- seq(51,99,by=3)
+  else
+  {
+    if(min(level) > 0 & max(level) < 1)
+      level <- 100*level
+    else if(min(level) < 0 | max(level) > 99.99)
+      stop("Confidence limit out of range")
+  }
+  nconf <- length(level)
+  z <- qnorm(.5 + level/200)
+  lower <- upper <- matrix(NA,nrow=h,ncol=nconf)
+  for(i in 1:nconf)
+  {
+    lower[,i] <- f - z[i]*se
+    upper[,i] <- f + z[i]*se
+  }
+  lower <- ts(lower,start=tsp(x)[2]+1/freq,f=freq)
+  upper <- ts(upper,start=tsp(x)[2]+1/freq,f=freq)
+  colnames(lower) <- colnames(upper) <- paste(level,"%",sep="")
+  fcast <- ts(f,start=tsp(x)[2]+1/freq,f=freq)
+  fits <- x - res
+  if(!is.null(lambda))
+  {
+    x <- origx
+    fcast <- InvBoxCox(fcast,lambda)
+    fits <- InvBoxCox(fits,lambda)
+    upper <- InvBoxCox(upper,lambda)
+    lower <- InvBoxCox(lower,lambda)
+  }
 
-    junk <- list(method=method,level=level,x=x,xname=xname,mean=fcast,lower=lower,upper=upper,
-        model=list(drift=b,drift.se=b.se,sd=s), fitted = fits, residuals = res, lambda=lambda)
-    junk$model$call <- match.call()
+  junk <- list(method=method,level=level,x=x,xname=xname,mean=fcast,lower=lower,upper=upper,
+      model=list(drift=b,drift.se=b.se,sd=s), fitted = fits, residuals = res, lambda=lambda)
+  junk$model$call <- match.call()
 
-    return(structure(junk,class="forecast"))
+  return(structure(junk,class="forecast"))
 }
 
 BoxCox <- function(x,lambda)
@@ -331,12 +332,12 @@ croston2 <- function(x,h=10,alpha=0.1,nofits=FALSE)
 }
 
 
-snaive <- function(x,h=2*frequency(x),level=c(80,95),fan=FALSE)
+snaive <- function(x,h=2*frequency(x),level=c(80,95),fan=FALSE, lambda=NULL)
 {
-    forecast(Arima(x,seasonal=list(order=c(0,1,0),period=frequency(x))),h=h,level=level,fan=fan)
+    forecast(Arima(x,seasonal=list(order=c(0,1,0),period=frequency(x)), lambda=lambda),h=h,level=level,fan=fan)
 }
 
-naive <- function(x,h=10,level=c(80,95),fan=FALSE)
+naive <- function(x,h=10,level=c(80,95),fan=FALSE, lambda=NULL)
 {
-    forecast(Arima(x,order=c(0,1,0)),h,level=level,fan=fan)
+    forecast(Arima(x,order=c(0,1,0),lambda=lambda),h,level=level,fan=fan)
 }
